@@ -30,7 +30,7 @@ def json_cast(obj):
 class JmesPathContainerMixin():
 
     def jp(self, expr):
-        return _jpr(expr, self)
+        return _jpr(expr, json_cast(self))
 
 
 class JpDict(JmesPathContainerMixin, dict):
